@@ -65,7 +65,7 @@ define([
             this.data = {
                 // Configuration
                 'vpcfg': {
-                    
+                    'runType': 'run'
                 },
                 // User defined code for Snippets
                 'vpudf': {
@@ -75,7 +75,8 @@ define([
                         'import matplotlib.pyplot as plt',
                         '%matplotlib inline',
                         'import seaborn as sns',
-                        'import plotly.express as px'
+                        'import plotly.express as px',
+                        'import pyarrow as pa'
                     ],
                     'matplotlib customizing': [
                         'import matplotlib.pyplot as plt',
@@ -132,7 +133,8 @@ define([
                             'from plotly.offline import init_notebook_mode',
                             'init_notebook_mode(connected=True)'
                         ]
-                    }
+                    },
+                    { library: 'pyarrow', alias:'pa' },
                 ]
             }
 
@@ -208,6 +210,10 @@ define([
                 'sm': {
                     code: 'import statsmodels.api as sm',
                     type: 'package'
+                },
+                'pyarrow': {
+                    code: 'import pyarrow as pa',
+                    type: 'package'
                 }
             }
 
@@ -636,7 +642,7 @@ define([
         /**
          * Set configuration data (on server)
          * @param {Object} dataObj 
-         * @param {String} configKey 
+         * @param {String} configKey vpcfg / vpudf / vpimport / vppackman
          */
         setData(dataObj, configKey='vpudf') {
             let that = this;
@@ -844,7 +850,7 @@ define([
                             throw new Error('Error', response);
                         }
                     }).then(function (data) {
-                        resolve(data.info.version);
+                        resolve(data.info.version, data.releases);
                     }).catch(function(err) {
                         let errMsg = err.message;
                         if (errMsg.includes('Failed to fetch')) {
@@ -904,14 +910,29 @@ define([
                 packageName = 'jupyterlab-visualpython';
             }
             this.getPackageVersion(packageName).then(function(latestVersion) {
-                if (nowVersion === latestVersion) {
+                let showUpdater = false;
+                if (nowVersion !== latestVersion) {
+                    let nowVerParts = nowVersion.split('.').map(x => ~~x);
+                    let latVerParts = latestVersion.split('.').map(x => ~~x);
+                    for (var i = 0; i < nowVerParts.length; i++) {
+                        const a = nowVerParts[i];
+                        const b = latVerParts[i];
+                        if (a < b) {
+                            showUpdater = true;
+                            break;
+                        } else if (a > b) {
+                            break;
+                        }
+                    }
+                }
+                if (showUpdater === false) {
                     // if it's already up to date
                     // hide version update icon
                     $('#vp_versionUpdater').hide();
-                    if (background) {
+                    if (background === true) {
                         ;
                     } else {
-                        let msg = com_util.formatString('Visual Python is up to date. ({0})', latestVersion);
+                        let msg = com_util.formatString('Visual Python is up to date. ({0})', nowVersion);
                         com_util.renderInfoModal(msg);
                     }
                     // update version_timestamp
@@ -1052,7 +1073,7 @@ define([
     /**
      * Version
      */
-    Config.version = "2.4.8";
+    Config.version = "3.0.1";
 
     /**
      * Type of mode
@@ -1103,11 +1124,11 @@ define([
     Config.ML_DATA_DICT = {
         'Data Preparation': [
             /** Encoding */
-            'OneHotEncoder', 'LabelEncoder', 'OrdinalEncoder', 'TargetEncoder', 'SMOTE',
+            'OneHotEncoder', 'LabelEncoder', 'OrdinalEncoder', 'TargetEncoder',
             /** Scaling */
             'StandardScaler', 'RobustScaler', 'MinMaxScaler', 'Normalizer', 'FunctionTransformer', 'PolynomialFeatures', 'KBinsDiscretizer',
             /** ETC */
-            'SimpleImputer', 'ColumnTransformer'
+            'SimpleImputer', 'SMOTE', 'ColumnTransformer'
         ],
         'Regression': [
             'LinearRegression', 'Ridge', 'Lasso', 'ElasticNet', 'SVR', 'DecisionTreeRegressor', 'RandomForestRegressor', 'GradientBoostingRegressor', 'XGBRegressor', 'LGBMRegressor', 'CatBoostRegressor',
